# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestNormalizedCommodityTargetComparisonMonthly(Model):
    """PlaceDigestNormalizedCommodityTargetComparisonMonthly.

    :param target_year: Target Year
    :type target_year: int
    :param target_label: Target Label
    :type target_label: str
    :param results: Monthly Target Data
    :type results:
     list[~energycap.sdk.models.PlaceDigestNormalizedCommodityTargetComparisonMonthlyCommodityResults]
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'results': {'key': 'results', 'type': '[PlaceDigestNormalizedCommodityTargetComparisonMonthlyCommodityResults]'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestNormalizedCommodityTargetComparisonMonthly, self).__init__(**kwargs)
        self.target_year = kwargs.get('target_year', None)
        self.target_label = kwargs.get('target_label', None)
        self.results = kwargs.get('results', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SingleValue(Model):
    """SingleValue.

    :param value:
    :type value: object
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'object'},
    }

    def __init__(self, **kwargs):
        super(SingleValue, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsResponse(Model):
    """EnergyStarSettingsResponse.

    :param pm_account_manager_full_name: Full name of Portfolio Account
     Manager
    :type pm_account_manager_full_name: str
    :param pm_account_manager_user_name: User name of Portfolio Account
     Manager
    :type pm_account_manager_user_name: str
    :param notification_recipients: List of e-mail notification recipients
    :type notification_recipients: list[str]
    :param earliest_submission_period: The earliest period to submit
    :type earliest_submission_period: int
    """

    _attribute_map = {
        'pm_account_manager_full_name': {'key': 'pmAccountManagerFullName', 'type': 'str'},
        'pm_account_manager_user_name': {'key': 'pmAccountManagerUserName', 'type': 'str'},
        'notification_recipients': {'key': 'notificationRecipients', 'type': '[str]'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarSettingsResponse, self).__init__(**kwargs)
        self.pm_account_manager_full_name = kwargs.get('pm_account_manager_full_name', None)
        self.pm_account_manager_user_name = kwargs.get('pm_account_manager_user_name', None)
        self.notification_recipients = kwargs.get('notification_recipients', None)
        self.earliest_submission_period = kwargs.get('earliest_submission_period', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpdatedOnlyResult(Model):
    """UpdatedOnlyResult.

    :param updated:  <span class='property-internal'>Required (defined)</span>
    :type updated: int
    """

    _attribute_map = {
        'updated': {'key': 'updated', 'type': 'int'},
    }

    def __init__(self, *, updated: int=None, **kwargs) -> None:
        super(UpdatedOnlyResult, self).__init__(**kwargs)
        self.updated = updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingImportProfile(Model):
    """ReadingImportProfile.

    All required parameters must be populated in order to send to Azure.

    :param channel_interval_in_seconds: The interval of the readings in
     seconds
    :type channel_interval_in_seconds: int
    :param delimiter: Required. The string that represents how the file
     contents are delimited.  Valid options are "\\t" for tab, " " for space
     and "," for comma. <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 2 characters</span> <span
     class='property-internal'>One of 	,  , , </span>
    :type delimiter: str
    :param number_of_header_rows: Required. Number of header rows before the
     data begins <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 2147483647</span>
    :type number_of_header_rows: int
    :param timestamp_column_number: The number of the column that holds the
     timestamp <span class='property-internal'>Must be between 1 and
     2147483647</span>
    :type timestamp_column_number: int
    :param timestamp_format: The format for the timestamp of the readings. An
     example is MM/dd/yyyy mm:hh:ss:zzz
    :type timestamp_format: str
    :param date_column_number: The number of the column that holds the date
     <span class='property-internal'>Must be between 1 and 2147483647</span>
    :type date_column_number: int
    :param time_column_number: The number of the column that holds the time
     <span class='property-internal'>Must be between 1 and 2147483647</span>
    :type time_column_number: int
    :param date_format: The format for the date of the readings. An example is
     MM/dd/yyyy
    :type date_format: str
    :param time_format: The format for the time of the readings. An example is
     mm:hh:ss:zzz
    :type time_format: str
    :param time_zone_id: The time zone for the readings
    :type time_zone_id: int
    :param meter_import_id_column_number: The number of the column that holds
     the meter import identifier <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type meter_import_id_column_number: int
    :param channel_import_id_column_number: The number of the column that
     holds the channel import identifier <span class='property-internal'>Must
     be between 1 and 2147483647</span>
    :type channel_import_id_column_number: int
    :param number_of_columns: Required. The minimum number of columns in the
     import sheet <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 2147483647</span>
    :type number_of_columns: int
    :param data_mapping: A list of columns from the import sheet with their
     observation type and unit
    :type data_mapping: list[~energycap.sdk.models.ReadingImportProfileColumn]
    :param estimated:
    :type estimated: ~energycap.sdk.models.Estimated
    :param note_column_number: Column number that holds a note to be stored
     with the reading <span class='property-internal'>Must be between 1 and
     2147483647</span>
    :type note_column_number: int
    """

    _validation = {
        'delimiter': {'required': True, 'max_length': 2, 'min_length': 1},
        'number_of_header_rows': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'timestamp_column_number': {'maximum': 2147483647, 'minimum': 1},
        'date_column_number': {'maximum': 2147483647, 'minimum': 1},
        'time_column_number': {'maximum': 2147483647, 'minimum': 1},
        'meter_import_id_column_number': {'maximum': 2147483647, 'minimum': 1},
        'channel_import_id_column_number': {'maximum': 2147483647, 'minimum': 1},
        'number_of_columns': {'required': True, 'maximum': 2147483647, 'minimum': 1},
        'note_column_number': {'maximum': 2147483647, 'minimum': 1},
    }

    _attribute_map = {
        'channel_interval_in_seconds': {'key': 'channelIntervalInSeconds', 'type': 'int'},
        'delimiter': {'key': 'delimiter', 'type': 'str'},
        'number_of_header_rows': {'key': 'numberOfHeaderRows', 'type': 'int'},
        'timestamp_column_number': {'key': 'timestampColumnNumber', 'type': 'int'},
        'timestamp_format': {'key': 'timestampFormat', 'type': 'str'},
        'date_column_number': {'key': 'dateColumnNumber', 'type': 'int'},
        'time_column_number': {'key': 'timeColumnNumber', 'type': 'int'},
        'date_format': {'key': 'dateFormat', 'type': 'str'},
        'time_format': {'key': 'timeFormat', 'type': 'str'},
        'time_zone_id': {'key': 'timeZoneId', 'type': 'int'},
        'meter_import_id_column_number': {'key': 'meterImportIdColumnNumber', 'type': 'int'},
        'channel_import_id_column_number': {'key': 'channelImportIdColumnNumber', 'type': 'int'},
        'number_of_columns': {'key': 'numberOfColumns', 'type': 'int'},
        'data_mapping': {'key': 'dataMapping', 'type': '[ReadingImportProfileColumn]'},
        'estimated': {'key': 'estimated', 'type': 'Estimated'},
        'note_column_number': {'key': 'noteColumnNumber', 'type': 'int'},
    }

    def __init__(self, *, delimiter: str, number_of_header_rows: int, number_of_columns: int, channel_interval_in_seconds: int=None, timestamp_column_number: int=None, timestamp_format: str=None, date_column_number: int=None, time_column_number: int=None, date_format: str=None, time_format: str=None, time_zone_id: int=None, meter_import_id_column_number: int=None, channel_import_id_column_number: int=None, data_mapping=None, estimated=None, note_column_number: int=None, **kwargs) -> None:
        super(ReadingImportProfile, self).__init__(**kwargs)
        self.channel_interval_in_seconds = channel_interval_in_seconds
        self.delimiter = delimiter
        self.number_of_header_rows = number_of_header_rows
        self.timestamp_column_number = timestamp_column_number
        self.timestamp_format = timestamp_format
        self.date_column_number = date_column_number
        self.time_column_number = time_column_number
        self.date_format = date_format
        self.time_format = time_format
        self.time_zone_id = time_zone_id
        self.meter_import_id_column_number = meter_import_id_column_number
        self.channel_import_id_column_number = channel_import_id_column_number
        self.number_of_columns = number_of_columns
        self.data_mapping = data_mapping
        self.estimated = estimated
        self.note_column_number = note_column_number



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsRequest(Model):
    """EnergyStarSettingsRequest.

    All required parameters must be populated in order to send to Azure.

    :param notification_recipients: Required. List of e-mail notification
     recipients <span class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type notification_recipients: list[str]
    :param earliest_submission_period: Required. The earliest period to submit
     <span class='property-internal'>Required</span>
    :type earliest_submission_period: int
    """

    _validation = {
        'notification_recipients': {'required': True},
        'earliest_submission_period': {'required': True},
    }

    _attribute_map = {
        'notification_recipients': {'key': 'notificationRecipients', 'type': '[str]'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarSettingsRequest, self).__init__(**kwargs)
        self.notification_recipients = kwargs.get('notification_recipients', None)
        self.earliest_submission_period = kwargs.get('earliest_submission_period', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodUseCostDeltaChild(Model):
    """BillingPeriodUseCostDeltaChild.

    :param billing_period: The billing period that the data represents.
     Will be the current billing period, the same year prior billing period,
     or the same period prior year billing period.
    :type billing_period: int
    :param use:
    :type use: ~energycap.sdk.models.BillingPeriodUseUnitDeltaChild
    :param cost:
    :type cost: ~energycap.sdk.models.BillingPeriodCostUnitDeltaChild
    """

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'use': {'key': 'use', 'type': 'BillingPeriodUseUnitDeltaChild'},
        'cost': {'key': 'cost', 'type': 'BillingPeriodCostUnitDeltaChild'},
    }

    def __init__(self, **kwargs):
        super(BillingPeriodUseCostDeltaChild, self).__init__(**kwargs)
        self.billing_period = kwargs.get('billing_period', None)
        self.use = kwargs.get('use', None)
        self.cost = kwargs.get('cost', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserCreateRequest(Model):
    """UserCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param user_code: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 65 characters</span>
    :type user_code: str
    :param full_name: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type full_name: str
    :param password: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type password: str
    :param email: Required.  <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 0 and 128
     characters</span>
    :type email: str
    :param cost_center_id: NOTE: This property will be deprecated
     Use TopmostCostCenterIds with a single valued list to create a user with a
     single topmost cost center
     Create User with a single topmost cost center id
     The CostCenterId must be in the creating user's topmost
     If this value is not null then TopmostCostCenterIds must be null <span
     class='property-internal'>Topmost (CostCenter)</span>
    :type cost_center_id: int
    :param topmost_cost_center_ids: Create User with one or multiple topmost
     cost center ids
     The CostCenterIds must be in the creating user's topmost
     If this is not null then CostCenterId must be null <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>NULL Valid</span>
    :type topmost_cost_center_ids: list[int]
    :param place_id: NOTE: This property will be deprecated
     Use TopmostPlaceIds with a single valued list to create a user with a
     single topmost place
     Create User with a single topmost place id
     The PlaceId must be in the creating user's topmost
     If this value is not null then TopmostPlaceIds must be null <span
     class='property-internal'>Topmost (Place)</span>
    :type place_id: int
    :param topmost_place_ids: Create User with one or multiple topmost place
     ids
     The PlaceIds must be in the creating user's topmost
     If this is not null then PlaceId must be null <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>NULL Valid</span>
    :type topmost_place_ids: list[int]
    :param active_directory:
    :type active_directory: bool
    :param active:
    :type active: bool
    :param password_expiration_interval: Required.  <span
     class='property-internal'>Required</span>
    :type password_expiration_interval: int
    :param strong_password: Required.  <span
     class='property-internal'>Required</span>
    :type strong_password: bool
    :param force_password_change: Required.  <span
     class='property-internal'>Required</span>
    :type force_password_change: bool
    :param user_role_id: Required.  <span
     class='property-internal'>Required</span>
    :type user_role_id: int
    :param max_approval_amount:
    :type max_approval_amount: int
    :param report_group_id:
    :type report_group_id: int
    :param user_groups: List of user group ids
     If null, empty, or not passed the user will not be assigned to any groups
    :type user_groups: list[int]
    """

    _validation = {
        'user_code': {'required': True, 'max_length': 65, 'min_length': 0},
        'full_name': {'required': True, 'max_length': 32, 'min_length': 0},
        'password': {'required': True, 'max_length': 128, 'min_length': 0},
        'email': {'required': True, 'max_length': 128, 'min_length': 0},
        'password_expiration_interval': {'required': True},
        'strong_password': {'required': True},
        'force_password_change': {'required': True},
        'user_role_id': {'required': True},
    }

    _attribute_map = {
        'user_code': {'key': 'userCode', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
        'password': {'key': 'password', 'type': 'str'},
        'email': {'key': 'email', 'type': 'str'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'topmost_cost_center_ids': {'key': 'topmostCostCenterIds', 'type': '[int]'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'topmost_place_ids': {'key': 'topmostPlaceIds', 'type': '[int]'},
        'active_directory': {'key': 'activeDirectory', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'password_expiration_interval': {'key': 'passwordExpirationInterval', 'type': 'int'},
        'strong_password': {'key': 'strongPassword', 'type': 'bool'},
        'force_password_change': {'key': 'forcePasswordChange', 'type': 'bool'},
        'user_role_id': {'key': 'userRoleId', 'type': 'int'},
        'max_approval_amount': {'key': 'maxApprovalAmount', 'type': 'int'},
        'report_group_id': {'key': 'reportGroupId', 'type': 'int'},
        'user_groups': {'key': 'userGroups', 'type': '[int]'},
    }

    def __init__(self, **kwargs):
        super(UserCreateRequest, self).__init__(**kwargs)
        self.user_code = kwargs.get('user_code', None)
        self.full_name = kwargs.get('full_name', None)
        self.password = kwargs.get('password', None)
        self.email = kwargs.get('email', None)
        self.cost_center_id = kwargs.get('cost_center_id', None)
        self.topmost_cost_center_ids = kwargs.get('topmost_cost_center_ids', None)
        self.place_id = kwargs.get('place_id', None)
        self.topmost_place_ids = kwargs.get('topmost_place_ids', None)
        self.active_directory = kwargs.get('active_directory', None)
        self.active = kwargs.get('active', None)
        self.password_expiration_interval = kwargs.get('password_expiration_interval', None)
        self.strong_password = kwargs.get('strong_password', None)
        self.force_password_change = kwargs.get('force_password_change', None)
        self.user_role_id = kwargs.get('user_role_id', None)
        self.max_approval_amount = kwargs.get('max_approval_amount', None)
        self.report_group_id = kwargs.get('report_group_id', None)
        self.user_groups = kwargs.get('user_groups', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserResponse(Model):
    """UserResponse.

    :param user_id: User Identifier
    :type user_id: int
    :param user_code: User Code
    :type user_code: str
    :param full_name: Full name of the user
    :type full_name: str
    :param user_role:
    :type user_role: ~energycap.sdk.models.SystemUserRoleChild
    :param cost_center:
    :type cost_center: ~energycap.sdk.models.TopmostCostCenter
    :param place:
    :type place: ~energycap.sdk.models.TopmostPlace
    :param active_directory: Is this a active directory user?
    :type active_directory: bool
    :param active: User is active or inactive
    :type active: bool
    :param email: Email ID of the user
    :type email: str
    :param password_expiration_interval: Days until password expires
    :type password_expiration_interval: int
    :param strong_password: Does user need a strong password - at least 8
     character long, one upper case, one number, one special char
    :type strong_password: bool
    :param force_password_change: Should the user be forced to change password
     on next login
    :type force_password_change: bool
    :param max_approval_amount: Max Total cost of bill this user is allowed to
     approve
    :type max_approval_amount: int
    :param last_login: last time the user logged in
    :type last_login: datetime
    :param report_group:
    :type report_group: ~energycap.sdk.models.ReportGroupChildResponse
    :param external_user_id: The external identifier for the user. This is
     only used for federated login.
    :type external_user_id: str
    :param user_groups: List of groups a user is a part of
    :type user_groups: list[~energycap.sdk.models.UserGroupChild]
    """

    _attribute_map = {
        'user_id': {'key': 'userId', 'type': 'int'},
        'user_code': {'key': 'userCode', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
        'user_role': {'key': 'userRole', 'type': 'SystemUserRoleChild'},
        'cost_center': {'key': 'costCenter', 'type': 'TopmostCostCenter'},
        'place': {'key': 'place', 'type': 'TopmostPlace'},
        'active_directory': {'key': 'activeDirectory', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'email': {'key': 'email', 'type': 'str'},
        'password_expiration_interval': {'key': 'passwordExpirationInterval', 'type': 'int'},
        'strong_password': {'key': 'strongPassword', 'type': 'bool'},
        'force_password_change': {'key': 'forcePasswordChange', 'type': 'bool'},
        'max_approval_amount': {'key': 'maxApprovalAmount', 'type': 'int'},
        'last_login': {'key': 'lastLogin', 'type': 'iso-8601'},
        'report_group': {'key': 'reportGroup', 'type': 'ReportGroupChildResponse'},
        'external_user_id': {'key': 'externalUserId', 'type': 'str'},
        'user_groups': {'key': 'userGroups', 'type': '[UserGroupChild]'},
    }

    def __init__(self, **kwargs):
        super(UserResponse, self).__init__(**kwargs)
        self.user_id = kwargs.get('user_id', None)
        self.user_code = kwargs.get('user_code', None)
        self.full_name = kwargs.get('full_name', None)
        self.user_role = kwargs.get('user_role', None)
        self.cost_center = kwargs.get('cost_center', None)
        self.place = kwargs.get('place', None)
        self.active_directory = kwargs.get('active_directory', None)
        self.active = kwargs.get('active', None)
        self.email = kwargs.get('email', None)
        self.password_expiration_interval = kwargs.get('password_expiration_interval', None)
        self.strong_password = kwargs.get('strong_password', None)
        self.force_password_change = kwargs.get('force_password_change', None)
        self.max_approval_amount = kwargs.get('max_approval_amount', None)
        self.last_login = kwargs.get('last_login', None)
        self.report_group = kwargs.get('report_group', None)
        self.external_user_id = kwargs.get('external_user_id', None)
        self.user_groups = kwargs.get('user_groups', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestEnergyUseIntensityEuiEnergyProject(Model):
    """PlaceDigestEnergyUseIntensityEuiEnergyProject.

    :param energy_project_id: The energy project identifier
    :type energy_project_id: int
    :param energy_project_code: The energy project code
    :type energy_project_code: str
    :param energy_project_info: The energy project info
    :type energy_project_info: str
    :param installation_cost: The energy project installation cost
    :type installation_cost: float
    """

    _attribute_map = {
        'energy_project_id': {'key': 'energyProjectId', 'type': 'int'},
        'energy_project_code': {'key': 'energyProjectCode', 'type': 'str'},
        'energy_project_info': {'key': 'energyProjectInfo', 'type': 'str'},
        'installation_cost': {'key': 'installationCost', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestEnergyUseIntensityEuiEnergyProject, self).__init__(**kwargs)
        self.energy_project_id = kwargs.get('energy_project_id', None)
        self.energy_project_code = kwargs.get('energy_project_code', None)
        self.energy_project_info = kwargs.get('energy_project_info', None)
        self.installation_cost = kwargs.get('installation_cost', None)
